@@ -4,10 +4,10 @@ $(() => {
             text() {
                 // Retrieve content from custom attribute of the $('.selector') elements.
                 return $(this).data('qtip-content');
-            }
+            },
         },
         show: {
-            solo: true
+            solo: true,
         },
         position: {
             viewport: $(window),
@@ -15,15 +15,15 @@ $(() => {
             at: 'center left',
             adjust: {
                 y: 0,
-                x: -6
-            }
+                x: -6,
+            },
         },
         style: {
             tip: {
                 corner: true,
-                method: 'polygon'
+                method: 'polygon',
             },
-            classes: 'qtip-rounded qtip-shadow ui-tooltip-sb'
-        }
+            classes: 'qtip-rounded qtip-shadow ui-tooltip-sb',
+        },
     });
 });
