@@ -9,10 +9,6 @@ import traceback
 from logging import NullHandler
 from urllib.parse import quote
 
-from sickchill.init_helpers import setup_lib_path
-
-setup_lib_path()
-
 from github import InputFileContent
 from github.GithubException import RateLimitExceededException, TwoFactorException
 
@@ -471,7 +467,7 @@ debug = Wrapper.instance.logger.debug
 info = Wrapper.instance.logger.info
 warning = Wrapper.instance.logger.warning
 error = Wrapper.instance.logger.error
-exception = logging.exception
+exception = error
 critical = Wrapper.instance.logger.critical
 
 
