@@ -19,7 +19,7 @@ class SearchResult(object):
         self.show = None
 
         # URL to the NZB/torrent file
-        self.url = ''
+        self.url = ""
 
         # used by some providers to store extra info associated with the result
         self.extraInfo = []
@@ -31,13 +31,13 @@ class SearchResult(object):
         self.quality = Quality.UNKNOWN
 
         # release name
-        self.name = ''
+        self.name = ""
 
         # size of the release (-1 = n/a)
         self.size = -1
 
         # release group
-        self.release_group = ''
+        self.release_group = ""
 
         # version
         self.version = -1
@@ -48,25 +48,27 @@ class SearchResult(object):
         # content
         self.content = None
 
-        self.resultType = ''
+        self.resultType = ""
+
+        self.priority = 0
 
     def from_json(self, result_dict):
-        self.name = result_dict.get('name')
-        self.url = result_dict.get('url')
-        self.size = result_dict.get('size')
-        self.version = result_dict.get('version')
-        self.release_group = result_dict.get('release_group')
-        self.quality = int(result_dict.get('quality'))
-        self.provider = sickchill.oldbeard.providers.getProviderClass(result_dict.get('provider'))
+        self.name = result_dict.get("name")
+        self.url = result_dict.get("url")
+        self.size = result_dict.get("size")
+        self.version = result_dict.get("version")
+        self.release_group = result_dict.get("release_group")
+        self.quality = int(result_dict.get("quality"))
+        self.provider = sickchill.oldbeard.providers.getProviderClass(result_dict.get("provider"))
 
     @classmethod
     def make_result(cls, result_dict):
-        show = sickchill.show.Show.Show._validate_indexer_id(result_dict.get('indexerid'))
+        show = sickchill.show.Show.Show._validate_indexer_id(result_dict.get("indexerid"))
         if not show[1]:
             return show[0]
 
         show = show[1]
-        episode_objects = [show.getEpisode(result_dict.get('season'), ep) for ep in result_dict.get('episodes').split('|') if ep]
+        episode_objects = [show.getEpisode(result_dict.get("season"), ep) for ep in result_dict.get("episodes").split("|") if ep]
         result = cls(episode_objects)
         result.from_json(result_dict)
         result.show = show
@@ -76,21 +78,21 @@ class SearchResult(object):
     def __str__(self):
 
         if self.provider is None:
-            return 'Invalid provider, unable to print self'
+            return "Invalid provider, unable to print self"
 
-        my_string = '{0} @ {1}\n'.format(self.provider.name, self.url)
-        my_string += 'Extra Info:\n'
+        my_string = "{0} @ {1}\n".format(self.provider.name, self.url)
+        my_string += "Extra Info:\n"
         for extra in self.extraInfo:
-            my_string += ' {0}\n'.format(extra)
+            my_string += " {0}\n".format(extra)
 
-        my_string += 'Episodes:\n'
+        my_string += "Episodes:\n"
         for ep in self.episodes:
-            my_string += ' {0}\n'.format(ep)
+            my_string += " {0}\n".format(ep)
 
-        my_string += 'Quality: {0}\n'.format(Quality.qualityStrings[self.quality])
-        my_string += 'Name: {0}\n'.format(self.name)
-        my_string += 'Size: {0}\n'.format(self.size)
-        my_string += 'Release Group: {0}\n'.format(self.release_group)
+        my_string += "Quality: {0}\n".format(Quality.qualityStrings[self.quality])
+        my_string += "Name: {0}\n".format(self.name)
+        my_string += "Size: {0}\n".format(self.size)
+        my_string += "Release Group: {0}\n".format(self.release_group)
 
         return my_string
 
@@ -102,7 +104,7 @@ class NZBSearchResult(SearchResult):
 
     def __init__(self, episodes):
         super().__init__(episodes)
-        self.resultType = 'nzb'
+        self.resultType = "nzb"
 
 
 class NZBDataSearchResult(SearchResult):
@@ -112,7 +114,7 @@ class NZBDataSearchResult(SearchResult):
 
     def __init__(self, episodes):
         super().__init__(episodes)
-        self.resultType = 'nzbdata'
+        self.resultType = "nzbdata"
 
 
 class TorrentSearchResult(SearchResult):
@@ -122,7 +124,7 @@ class TorrentSearchResult(SearchResult):
 
     def __init__(self, episodes):
         super().__init__(episodes)
-        self.resultType = 'torrent'
+        self.resultType = "torrent"
 
 
 class Proper(object):
@@ -144,9 +146,9 @@ class Proper(object):
         self.scene_episode = -1
 
     def __str__(self):
-        return '{date} {name} {season}x{episode} of {series_id} from {indexer}'.format(
-            date=self.date, name=self.name, season=self.season, episode=self.episode,
-            series_id=self.indexerid, indexer=sickchill.indexer.name(self.indexer))
+        return "{date} {name} {season}x{episode} of {series_id} from {indexer}".format(
+            date=self.date, name=self.name, season=self.season, episode=self.episode, series_id=self.indexerid, indexer=sickchill.indexer.name(self.indexer)
+        )
 
 
 class ErrorViewer(object):
