@@ -70,12 +70,12 @@ class DailySearcher(object):  # pylint:disable=too-few-public-methods
             ep = show.getEpisode(sqlEp["season"], sqlEp["episode"])
             with ep.lock:
                 if ep.season == 0:
-                    logger.info("New episode " + ep.pretty_name() + " airs today, setting status to SKIPPED because is a special season")
+                    logger.info("New episode " + ep.pretty_name + " airs today, setting status to SKIPPED because is a special season")
                     ep.status = common.SKIPPED
                 else:
                     logger.info(
                         "New episode {0} airs today, setting to default episode status for this show: {1}".format(
-                            ep.pretty_name(), common.statusStrings[ep.show.default_ep_status]
+                            ep.pretty_name, common.statusStrings[ep.show.default_ep_status]
                         )
                     )
                     ep.status = ep.show.default_ep_status
