@@ -2,15 +2,13 @@ import random
 from threading import Lock
 from typing import TYPE_CHECKING
 
-from .init_helpers import setup_gettext, setup_lib_path, sickchill_dir
-
-setup_lib_path()
-
 import rarfile
 
 from sickchill.oldbeard.common import SD
 from sickchill.oldbeard.numdict import NumDict
 
+from .init_helpers import setup_gettext, sickchill_dir
+
 if TYPE_CHECKING:
     from .movies import MovieList
 
@@ -65,6 +63,7 @@ ANIME_SPLIT_HOME = False
 ANIME_SPLIT_HOME_IN_TABS = False
 ANIMESUPPORT = False
 ANON_REDIRECT = None
+DEFAULT_ANON_REDIRECT = "https://blankrefer.com/?"
 API_KEY = None
 API_ROOT = None
 AUTO_UPDATE = False
