@@ -2,6 +2,7 @@ import os
 import shutil
 import tarfile
 import traceback
+from pathlib import Path
 
 from sickchill import logger, settings
 from sickchill.oldbeard import helpers, notifiers
@@ -45,12 +46,12 @@ class SourceUpdateManager(UpdateManagerBase):
         # need this to run first to set self._newest_commit_hash
         try:
             self._check_github_for_update()
-        except Exception as e:
-            logger.warning("Unable to contact github, can't check for update: " + repr(e))
+        except Exception as error:
+            logger.warning(f"Unable to contact github, can't check for update: {error}")
             return False
 
         if self.branch != self._find_installed_branch():
-            logger.debug("Branch checkout: " + self._find_installed_branch() + "->" + self.branch)
+            logger.debug(f"Branch checkout: {self._find_installed_branch()}->{self.branch}")
             return True
 
         if not self._cur_commit_hash or self._num_commits_behind > 0:
@@ -96,9 +97,7 @@ class SourceUpdateManager(UpdateManagerBase):
                 # when _cur_commit_hash doesn't match anything _num_commits_behind == 100
                 self._num_commits_behind += 1
 
-        logger.debug(
-            "cur_commit = {0}, newest_commit = {1}, num_commits_behind = {2}".format(self._cur_commit_hash, self._newest_commit_hash, self._num_commits_behind)
-        )
+        logger.debug(f"cur_commit = {self._cur_commit_hash}, newest_commit = {self._newest_commit_hash}, num_commits_behind = {self._num_commits_behind}")
 
     def set_newest_text(self):
         if not self._cur_commit_hash:
@@ -107,9 +106,7 @@ class SourceUpdateManager(UpdateManagerBase):
             update_url = self.get_update_url()
             newest_tag = "unknown_current_version"
             newest_text = _(
-                'Unknown current version number: If you\'ve never used the SickChill upgrade system before then current version is not set. &mdash; <a href="{update_url}">Update Now</a>'.format(
-                    update_url=update_url
-                )
+                f'Unknown current version number: If you\'ve never used the SickChill upgrade system before then current version is not set. &mdash; <a href="{update_url}">Update Now</a>'
             )
 
         elif self._num_commits_behind > 0:
@@ -125,9 +122,7 @@ class SourceUpdateManager(UpdateManagerBase):
             s = ("", "s")[commits_behind != 1]
             update_url = self.get_update_url()
             newest_text = _(
-                'There is a <a href="{url}" onclick="window.open(this.href); return false;">newer version available</a> (you\'re {commits_behind} commit{s} behind) &mdash; <a href="{update_url}">Update Now</a>'.format(
-                    commits_behind=commits_behind, update_url=update_url, url=url, s=s
-                )
+                f'There is a <a href="{url}" onclick="window.open(this.href); return false;">newer version available</a> (you\'re {commits_behind} commit{s} behind) &mdash; <a href="{update_url}">Update Now</a>'
             )
         else:
             return
@@ -139,56 +134,57 @@ class SourceUpdateManager(UpdateManagerBase):
         Downloads the latest source tarball from github and installs it over the existing version.
         """
 
-        tar_download_url = "https://github.com/" + settings.GIT_ORG + "/" + settings.GIT_REPO + "/tarball/" + self.branch
+        tar_download_url = f"https://github.com/{settings.GIT_ORG}/{settings.GIT_REPO}/tarball/{self.branch}"
 
         try:
             # prepare the update dir
-            sr_update_dir = os.path.join(settings.DATA_DIR, "sr-update")
+            sc_update_dir = Path(settings.DATA_DIR) / "sc-update"
 
-            if os.path.isdir(sr_update_dir):
-                logger.info("Clearing out update folder " + sr_update_dir + " before extracting")
-                shutil.rmtree(sr_update_dir)
+            if sc_update_dir.is_dir():
+                logger.info(f"Clearing out update folder {sc_update_dir} before extracting")
+                shutil.rmtree(sc_update_dir)
 
-            logger.info("Creating update folder " + sr_update_dir + " before extracting")
-            os.makedirs(sr_update_dir)
+            logger.info(f"Creating update folder {sc_update_dir} before extracting")
+            sc_update_dir.mkdir()
 
             # retrieve file
-            logger.info("Downloading update from {url}".format(url=tar_download_url))
-            tar_download_path = os.path.join(sr_update_dir, "sr-update.tar")
+            logger.info(f"Downloading update from {tar_download_url}")
+            tar_download_path = sc_update_dir / "sc-update.tar"
             helpers.download_file(tar_download_url, tar_download_path, session=self.session)
 
-            if not os.path.isfile(tar_download_path):
-                logger.warning("Unable to retrieve new version from " + tar_download_url + ", can't update")
+            if not tar_download_path.is_file():
+                logger.warning(f"Unable to retrieve new version from {tar_download_url}, can't update")
                 return False
 
             if not tarfile.is_tarfile(tar_download_path):
-                logger.exception("Retrieved version from " + tar_download_url + " is corrupt, can't update")
+                logger.exception(f"Retrieved version from {tar_download_url} is corrupt, can't update")
                 return False
 
-            # extract to sr-update dir
-            logger.info("Extracting file " + tar_download_path)
+            # extract to sc-update dir
+            logger.info(f"Extracting file {tar_download_path}")
             tar = tarfile.open(tar_download_path)
-            tar.extractall(sr_update_dir)
+            tar.extractall(sc_update_dir)
             tar.close()
 
             # delete .tar.gz
-            logger.info("Deleting file " + tar_download_path)
-            os.remove(tar_download_path)
+            logger.info(f"Deleting file {tar_download_path}")
+            tar_download_path.unlink(True)
 
             # find update dir name
-            update_dir_contents = [x for x in os.listdir(sr_update_dir) if os.path.isdir(os.path.join(sr_update_dir, x))]
+            update_dir_contents = [x for x in sc_update_dir.iterdir() if x.is_dir()]
 
             if len(update_dir_contents) != 1:
-                logger.exception("Invalid update data, update failed: " + str(update_dir_contents))
+                logger.exception(f"Invalid update data, update failed: {str(update_dir_contents)}")
                 return False
 
             # walk temp folder and move files to main folder
-            content_dir = os.path.join(sr_update_dir, update_dir_contents[0])
-            logger.info("Moving files from " + content_dir + " to " + os.path.dirname(settings.PROG_DIR))
+            content_dir = sc_update_dir / update_dir_contents[0]
+            logger.info(f"Moving files from {content_dir} to {os.path.dirname(settings.PROG_DIR)}")
+
             for dirname, stderr_, filenames in os.walk(content_dir):
                 dirname = dirname[len(content_dir) + 1 :]
                 for curfile in filenames:
-                    old_path = os.path.join(content_dir, dirname, curfile)
+                    old_path = content_dir / dirname / curfile
                     new_path = os.path.join(os.path.dirname(settings.PROG_DIR), dirname, curfile)
 
                     if os.path.isfile(new_path):
@@ -199,8 +195,8 @@ class SourceUpdateManager(UpdateManagerBase):
             settings.CUR_COMMIT_BRANCH = self.branch
 
         except Exception as error:
-            logger.exception("Error while trying to update: {}".format(error))
-            logger.debug("Traceback: {}".format(traceback.format_exc()))
+            logger.exception(f"Error while trying to update: {error}")
+            logger.debug(f"Traceback: {traceback.format_exc()}")
             return False
 
         # Notify update successful
