@@ -4,8 +4,10 @@ import datetime
 import json
 import os
 import time
+import traceback
 import urllib.parse
 from operator import attrgetter
+from pathlib import Path
 from urllib.parse import unquote_plus
 
 from github.GithubException import GithubException
@@ -345,23 +347,23 @@ class Home(WebRoot):
 
     @staticmethod
     def testTwilio():
-        if not notifiers.twilio_notifier.account_regex.match(settings.TWILIO_ACCOUNT_SID):
-            return _("Please enter a valid account sid")
-
-        if not notifiers.twilio_notifier.auth_regex.match(settings.TWILIO_AUTH_TOKEN):
-            return _("Please enter a valid auth token")
-
-        if not notifiers.twilio_notifier.phone_regex.match(settings.TWILIO_PHONE_SID):
-            return _("Please enter a valid phone sid")
-
-        if not notifiers.twilio_notifier.number_regex.match(settings.TWILIO_TO_NUMBER):
-            return _('Please format the phone number as "+1-###-###-####"')
-
-        result = notifiers.twilio_notifier.test_notify()
-        if result:
-            return _("Authorization successful and number ownership verified")
-        else:
-            return _("Error sending sms")
+        # if not notifiers.twilio_notifier.account_regex.match(settings.TWILIO_ACCOUNT_SID):
+        #     return _("Please enter a valid account sid")
+        #
+        # if not notifiers.twilio_notifier.auth_regex.match(settings.TWILIO_AUTH_TOKEN):
+        #     return _("Please enter a valid auth token")
+        #
+        # if not notifiers.twilio_notifier.phone_regex.match(settings.TWILIO_PHONE_SID):
+        #     return _("Please enter a valid phone sid")
+        #
+        # if not notifiers.twilio_notifier.number_regex.match(settings.TWILIO_TO_NUMBER):
+        #     return _('Please format the phone number as "+1-###-###-####"')
+        #
+        # result = notifiers.twilio_notifier.test_notify()
+        # if result:
+        #     return _("Authorization successful and number ownership verified")
+        # else:
+        return _("Error sending sms")
 
     @staticmethod
     def testSlack():
@@ -637,7 +639,7 @@ class Home(WebRoot):
         else:
             backend_dirs = []
 
-        if len(backend_dirs):
+        if backend_dirs:
             for subject in backend_dirs:
                 rootDir[subject] = helpers.disk_usage_hr(subject)
 
@@ -1039,7 +1041,7 @@ class Home(WebRoot):
 
                 if helpers.set_up_anidb_connection() and not anidb_failed:
                     try:
-                        anime = adba.Anime(settings.ADBA_CONNECTION, name=show_obj.name)
+                        anime = adba.Anime(settings.ADBA_CONNECTION, name=show_obj.name, cache_dir=Path(settings.CACHE_DIR))
                         groups = anime.get_groups()
                     except Exception as e:
                         ui.notifications.error(_("Unable to retreive Fansub Groups from AniDB."))
@@ -1107,7 +1109,7 @@ class Home(WebRoot):
             bestQualities = [bestQualities]
 
         if isinstance(exceptions_list, list):
-            if len(exceptions_list) > 0:
+            if exceptions_list:
                 exceptions_list = exceptions_list[0]
             else:
                 exceptions_list = None
@@ -1253,7 +1255,7 @@ class Home(WebRoot):
 
         logger.debug("Updating show exceptions")
         try:
-            sickchill.oldbeard.scene_exceptions.update_scene_exceptions(show_obj.indexerid, exceptions)
+            sickchill.oldbeard.scene_exceptions.update_custom_scene_exceptions(show_obj.indexerid, exceptions)
             time.sleep(cpu_presets[settings.CPU_PRESET])
         except CantUpdateShowException:
             logger.debug(traceback.format_exc())
@@ -1977,11 +1979,12 @@ class Home(WebRoot):
         logger.info("ReleaseGroups: {0}".format(show_name))
         if helpers.set_up_anidb_connection():
             try:
-                anime = adba.Anime(settings.ADBA_CONNECTION, name=show_name)
+                anime = adba.Anime(settings.ADBA_CONNECTION, name=show_name, cache_dir=Path(settings.CACHE_DIR))
                 groups = anime.get_groups()
                 logger.info("ReleaseGroups: {0}".format(groups))
                 return json.dumps({"result": "success", "groups": groups})
             except AttributeError as error:
                 logger.debug("Unable to get ReleaseGroups: {0}".format(error))
+                logger.debug(traceback.format_exc())
 
         return json.dumps({"result": "failure"})
